![Photo by GEORGE DESIPRIS from Pexels https://www.pexels.com/photo/man-in-santa-claus-costume-with-diving-gear-inside-aquarium-731141/](https://i.imgur.com/6SdlHMw.jpg)

IOTA-PearlDiver
===============

IOTA transaction nonce searcher python implement


How to use
==========

Clone this repository and use `pipenv install`, `pipenv shell`.


TODO
====

Why the hell pypy is slower than CPython? And why the hell you depend on numpy?
